Summary: The Linux kernel (the core of the Linux operating system)

# Build Options
%define buildup		1
%define buildsource	0
%define buildheaders	0
%define builddocs	0
%define builddevfs	0

# Define
%define sublevel 22
%define kversion 2.6.%{sublevel}
%define rpmversion 2.6.%{sublevel}
%define devfsdver 1.3.25
%define release b2

%define KVERREL %{PACKAGE_VERSION}-berry

# groups of related archs
%define all_x86 i386 i586 i686

%ifarch %{all_x86}
%define all_arch_configs kernel-%{kversion}-i?86*.config
%define _64bit 0
%endif

%ifarch x86_64
%define all_arch_configs kernel-%{kversion}-x86_64*.config
%define _64bit 1
%endif


#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 1.0.3, e2fsprogs < 1.29, util-linux < 2.10, jfsutils < 1.0.14, reiserfsprogs < 3.6.3, xfsprogs < 2.1.0, procps < 2.0.9, oprofile < 0.5.3

#
# Then a series of requirements that are Red Hat specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%define package_conflicts cipe < 1.4.5, tux < 2.1.0, kudzu <= 0.92, initscripts < 7.23, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0

#
# Several packages had bugs in them that became obvious when the NPTL
# threading code got integrated.
#
%define nptl_conflicts SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq	fileutils, module-init-tools, initscripts >= 5.83


Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}
ExclusiveArch: %{all_x86} x86_64
ExclusiveOS: Linux
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: glibc-kernheaders
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function
AutoReqProv: no
BuildArchitectures: i686
#BuildArchitectures: x86_64


# List the packages used during the kernel build
BuildPreReq: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, gzip, m4, perl, make >= 3.78
BuildRequires: gcc >= 2.96-98, binutils >= 2.12
BuildConflicts: rhbuildsys(DiskFree) < 500Mb

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2
%if %{builddevfs}
%package -n devfsd
Source1: ftp://ftp.atnf.csiro.au/pub/people/rgooch/linux/daemons/devfsd-v%{devfsdver}.tar.bz2
%endif

Source20: berry-%{kversion}.config
Source21: berry-64.config

Patch1000: linux-2.4.0-test11-vidfail.patch

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root


# desc
%description
The kernel package contains the Linux kernel (vmlinuz), the core of your
Red Hat Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%package source
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: make >= 3.78
Requires: gcc >= 3.2
Requires: /usr/bin/strip
# for xconfig and gconfig
#Requires: qt-devel, gtk2-devel readline-devel

%description source
The kernel-source package contains the source code files for the Linux
kernel. The source files can be used to build a custom kernel that is better
tuned to your particular hardware, if you are so inclined (and you know what
you're doing). The customisation guide in the documentation describes in
detail how to do this. This package is not needed nor usable for building
external kernel modules for linking into the default kernel.

%package headers
Summary: Header files for the Linux kernel.
Group: Development/System

%description headers
Kernel-headers includes the C header files for the Linux kernel.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
kernel.

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%if %{builddevfs}
%package -n devfsd
Summary: Device filesystem management daemon
Group: System Environment/Kernel
Requires: kernel >= 2.3.46

%description -n devfsd
Daemon for managing the device filesystem (devfs)
%endif


# prep
%prep

#%setup -q -n %{name}-%{version} -c -a 1
%setup -q -n %{name}-%{version} -c
cd linux-%{kversion}
%if %{builddevfs}
mv ../devfsd* .
%endif

# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
#%patch500 -p1

# add vidfail capability;
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer cd that wants to automatically fall back to textmode
# in that case
%patch1000 -p1

mkdir configs
cp %{SOURCE20} configs/kernel-%{kversion}-i686.config
cp %{SOURCE21} configs/kernel-%{kversion}-x86_64.config
cp -fv configs/%{all_arch_configs} .

# now run oldconfig over all the config files
for i in *.config
do
	mv $i .config
	#make ARCH=`echo $i | cut -d"-" -f3 | cut -d"." -f1 | sed -e s/i.86/i386/ -e s/s390x/s390/ -e s/ppc64.series/ppc64/ -e s/ppc8.../ppc/ -e s/ppc32dy4/ppc/ ` nonint_oldconfig > /dev/null
	make oldconfig > /dev/null
	mv .config configs/$i
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;


# build
%build

cd linux-%{kversion}

BuildKernel() {

    # Pick the right config file for the kernel we're building
    if [ -n "$1" ] ; then
	Config=kernel-%{kversion}-%{_target_cpu}-$1.config
    else
	Config=kernel-%{kversion}-%{_target_cpu}.config
    fi

    #KernelVer=%{version}-%{release}$1
    KernelVer=%{KVERREL}$1
    echo BUILDING A KERNEL FOR $1 %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    #perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$1/" Makefile
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -berry$1/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    #make -s nonint_oldconfig > /dev/null
    make -s oldconfig > /dev/null
    make -s include/linux/version.h

    make -s %{?_smp_mflags} bzImage
    make -s %{?_smp_mflags} modules || exit 1
    ##make buildcheck

    # Start installing the results

    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 System.map $RPM_BUILD_ROOT/usr/lib/debug/boot/System.map-$KernelVer
    objdump -t vmlinux | grep ksymtab | cut -f2 | cut -d" " -f2 | cut -c11- | sort -u  > exported
    echo "_stext" >> exported
    echo "_end" >> exported
    touch $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    for i in `cat exported`
    do
	 grep " $i\$" System.map >> $RPM_BUILD_ROOT/boot/System.map-$KernelVer || :
	 grep "tab_$i\$" System.map >> $RPM_BUILD_ROOT/boot/System.map-$KernelVer || :
	 grep "__crc_$i\$" System.map >> $RPM_BUILD_ROOT/boot/System.map-$KernelVer ||:
    done
    rm -f exported
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    rm -f System.map
    cp arch/*/boot/bzImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
    ##cp arch/*/boot/bzImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # first copy everything
    cp --parents `find -type f -name Makefile -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # since 2.6.15
    cp --parents `find -type f -name Makefile.cpu` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    ##cp arch/%{_arch}/kernel/asm-offsets.s $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/kernel || :
    cp arch/i386/kernel/asm-offsets.s $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/i386/kernel || :
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config linux math-emu media net pcmcia rxrpc scsi sound video asm asm-generic asm-i386 $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    cd ..

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer

    # move the modules in the SOURCE11 file to the unsupported/ directory so
    # that they end up in the -unsupported rpms
##    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/unsupported
##    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel ; {
##	 tar cf - `cat %{SOURCE11}`  | tar xf - -C ../unsupported
##	 rm -rf `cat %{SOURCE11}`
##    } ; popd


    # mark modules executable so that strip-to-file can strip them
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f | xargs chmod u+x

    # detect missing or incorrect license tags
    ##for i in `find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" ` ; do echo -n "$i " ; /sbin/modinfo -l $i >> modinfo ; done
    ##cat modinfo | grep -v "^GPL" | grep -v "^Dual BSD/GPL" | grep -v "^Dual MPL/GPL" | grep -v "^GPL and additional rights" | grep -v "^GPL v2" && exit 1
    ##rm -f modinfo
    # remove files that will be auto generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*
}

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{buildup}
BuildKernel
%endif

%if %{builddevfs}
# compile devfsd
cd devfsd
perl -pi -e "s,-O2,$RPM_OPT_FLAGS -D_GNU_SOURCE,g" GNUmakefile
make -s KERNEL_DIR=..
cd ..
%endif


# install
%install

cd linux-%{kversion}

# architectures that don't get kernel-source (i586/i686/athlon) dont need
# much of an install because the build phase already copied the needed files

%if %{buildsource}
mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# clean up the source tree so that it is ready for users to build their own
# kernel
make -s mrproper

# copy the source over
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# set the EXTRAVERSION to <version>custom, so that people who follow a kernel building howto
# don't accidentally overwrite their currently working moduleset and hose
# their system
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile
#install -m 644 %{SOURCE10} $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

mkdir -p $RPM_BUILD_ROOT/usr/src
ln -sf /usr/src/linux-%{KVERREL} $RPM_BUILD_ROOT/usr/src/linux-2.6
%endif

# /usr/include
mkdir -p $RPM_BUILD_ROOT/usr/include
ln -sf /lib/modules/%{KVERREL}/build/include/linux $RPM_BUILD_ROOT/usr/include/linux
ln -sf /lib/modules/%{KVERREL}/build/include/asm-i386 $RPM_BUILD_ROOT/usr/include/asm
ln -sf /lib/modules/%{KVERREL}/build/include/asm-generic $RPM_BUILD_ROOT/usr/include/asm-generic

%if %{builddevfs}
	# devfs
	mkdir -p $RPM_BUILD_ROOT/sbin $RPM_BUILD_ROOT%{_mandir}/man8 $RPM_BUILD_ROOT/etc
	install -m 755 -s devfsd/devfsd $RPM_BUILD_ROOT/sbin/devfsd
	cp -p devfsd/devfsd.8 $RPM_BUILD_ROOT%{_mandir}/man8
	cp -p devfsd/devfsd.conf $RPM_BUILD_ROOT/etc/devfsd.conf
	cp -p devfsd/modules.devfs $RPM_BUILD_ROOT/etc/modules.devfs

	%if %{buildsource}
		make -s clean -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/devfsd
		rm -f $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/devfsd/devfsd
	%endif
%endif


# clean
%clean
rm -rf $RPM_BUILD_ROOT


# scripts
%post
cd /boot
ln -sf vmlinuz-%{KVERREL} vmlinuz
ln -sf System.map-%{KVERREL} System.map
depmod -a -F /boot/System.map-%{KVERREL} %{KVERREL}

%preun
rm -f /lib/modules/%{KVERREL}/modules.*


# file lists
%if %{buildup}
%files
%defattr(-,root,root)
/boot/vmlinuz-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
%verify(not mtime) /lib/modules/%{KVERREL}/build
/usr/include/asm
/usr/include/asm-generic
/usr/include/linux
%endif

# only some architecture builds need kernel-source and kernel-doc
%if %{buildsource}

%files source
%defattr(-,root,root)
%dir /usr/src/linux-%{KVERREL}
/usr/src/linux-%{KVERREL}/COPYING
/usr/src/linux-%{KVERREL}/CREDITS
/usr/src/linux-%{KVERREL}/MAINTAINERS
/usr/src/linux-%{KVERREL}/Makefile
/usr/src/linux-%{KVERREL}/README
/usr/src/linux-%{KVERREL}/REPORTING-BUGS
/usr/src/linux-%{KVERREL}/arch/i386
/usr/src/linux-%{KVERREL}/crypto
/usr/src/linux-%{KVERREL}/drivers
/usr/src/linux-%{KVERREL}/fs
/usr/src/linux-%{KVERREL}/init
/usr/src/linux-%{KVERREL}/ipc
/usr/src/linux-%{KVERREL}/kernel
/usr/src/linux-%{KVERREL}/lib
/usr/src/linux-%{KVERREL}/mm
/usr/src/linux-%{KVERREL}/net
/usr/src/linux-%{KVERREL}/scripts
/usr/src/linux-%{KVERREL}/security
/usr/src/linux-%{KVERREL}/sound
/usr/src/linux-%{KVERREL}/usr
/usr/src/linux-%{KVERREL}/include/asm-i386
#/usr/src/linux-%{KVERREL}/include/asm
/usr/src/linux-%{KVERREL}/include/asm-generic
/usr/src/linux-%{KVERREL}/include/linux
/usr/src/linux-%{KVERREL}/include/acpi
/usr/src/linux-%{KVERREL}/include/math-emu
/usr/src/linux-%{KVERREL}/include/media
/usr/src/linux-%{KVERREL}/include/mtd
/usr/src/linux-%{KVERREL}/include/net
/usr/src/linux-%{KVERREL}/include/pcmcia
/usr/src/linux-%{KVERREL}/include/rxrpc
/usr/src/linux-%{KVERREL}/include/scsi
/usr/src/linux-%{KVERREL}/include/sound
/usr/src/linux-%{KVERREL}/include/video
/usr/src/linux-2.6
%if %{builddevfs}
/usr/src/linux-%{KVERREL}/devfsd
%endif

%if %{buildheaders}
%files headers
%defattr(-,root,root)
/usr/include/asm
/usr/include/asm-generic
/usr/include/linux
#/usr/src/linux-%{KVERREL}/include/asm-i386
#/usr/src/linux-%{KVERREL}/include/asm-generic
#/usr/src/linux-%{KVERREL}/include/linux
%verify(not mtime) /lib/modules/%{KVERREL}/build
%endif

%if %{builddocs}
%files doc
%defattr(-,root,root)
%doc /usr/src/linux-%{KVERREL}/Documentation/*
%endif

%endif

%if %{builddevfs}
%files -n devfsd
%defattr(-,root,root)
/sbin/devfsd
%{_mandir}/man8/devfsd.8*
%config /etc/devfsd.conf
%config /etc/modules.devfs
%endif


# change log
%changelog
* Mon Aug 13 2007 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.22.2
* Sun Jul 8 2007 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.21.6
* Wed Apr 18 2007 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.20.7
* Thu Feb 22 2007 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.20.1
* Sat Jan 13 2007 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.19.2
* Fri Dec 1 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.19
* Sun Nov 19 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.18.3
* Mon Oct 9 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.18
* Sun Sep 10 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.17.13
* Mon Aug 28 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.17.11
* Fri Jul 7 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.17.4
* Thu Jun 19 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.16.20
* Fri May 19 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.16.16
* Tue Apr 18 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.16.7
* Sat Feb 11 2006 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.15.4
* Mon Dec 19 2005 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.14.4
* Sun Nov 27 2005 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.14.3
* Fri Nov 4 2005 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.14
* Tue Sep 27 2005 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.12.5
* Tue Jul 19 2005 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.12.3
* Sun Jun 19 2005 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.12
* Tue May 17 2005 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.11.10
* Wed Apr 13 2005 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.11.7
- to i686
* Mon Nov 1 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.9
* Mon Oct 11 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.9-rc4
* Sat Aug 14 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.8
- Added /include/mtd/* files
* Mon Jul 12 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.8-rc1
* Thu Jul 8 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.7-bk20
* Thu May 24 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.7-rc1
* Mon May 10 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.6
* Wed Apr 28 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- /usr/src/linux-%{KVERREL} to /lib/modules/%{KVERREL}/
- Update to 2.6.6-rc3
* Sun Apr 4 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.5
* Sat Mar 20 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.5-rc2
* Thu Mar 11 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.4
* Wed Feb 18 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.3
* Wed Feb 11 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.3-rc2
* Wed Feb 4 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.2
* Thu Jan 29 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.2-rc3
* Mon Jan 12 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.1
* Thu Jan 8 2004 Yuichiro Nakada <berry@po.yui.mine.nu>
- Update to 2.6.1-rc3
* Sat Dec 20 2003 Yuichiro Nakada <berry@po.yui.mine.nu>
- Create for Berry Linux
- from Red Hat Fedora Core 1
